@@ -1,12 +1,12 @@
-from .page_creator import PageCreator
-from .hocr_parser import HocrParser
-from .textract_parser import TextractParser
-from .text_block import TextBlock, Document, Page, Paragraph, Line, Word, Character
 from .bounding_box import BoundingBox
 from .drawer import Drawer
-from .searchable_pdf import save_searchable_pdf
-from .text_block_splitter import TextBlockSplitter
+from .hocr_parser import HocrParser
+from .page_creator import PageCreator
 from .point import Point
+from .searchable_pdf import save_searchable_pdf
 from .segment import Segment
+from .text_block import Character, Document, Line, Page, Paragraph, TextBlock, Word
+from .text_block_splitter import TextBlockSplitter
+from .textract_parser import TextractParser
 
-__version__ = "1.0.16"
+__version__ = "1.0.194"
