@@ -1,5 +1,6 @@
 import abc
 from typing import Iterator, Optional, Generator, Union
+from docstruct.visual_detection.vis_line import VisLine
 from .bounding_box import BoundingBox
 from .ligatures import LIGATURES_TO_TEXT
 import logging
@@ -332,11 +333,12 @@ class Word(TextBlock):
 
     child_type = Character
 
-    def __init__(self, text: str, bounding_box: BoundingBox):
+    def __init__(self, text: str, bounding_box: BoundingBox, printed: bool = True):
         super().__init__(bounding_box=bounding_box)
         text = self.get_clean_text(text)
         chars_bboxes = BoundingBox.split_bounding_box(bounding_box, len(text))
         self.text = text
+        self.printed = printed
         for char, char_bbox in zip(text, chars_bboxes):
             self.add_child(Character(char_bbox, char))
 
@@ -391,6 +393,28 @@ class Page(TextBlock):
         The coordinates of the blocks are PDF coordinates (i.e. the origin is at the bottom left), and normalized to the page size."""
         return
 
+    def set_vis_lines(self, hor_vis_lines: list[VisLine], ver_vis_lines: list[VisLine]):
+        """
+        Set the horizontal and vertical lines of the page.
+        """
+        self.hor_vis_lines = hor_vis_lines
+        self.ver_vis_lines = ver_vis_lines
+
+    def set_tables(self, tables: list["Table"]):
+        """
+        Set the tables of the page.
+        """
+        self.tables = tables
+
+    def get_tables(self):
+        return getattr(self, "tables", [])
+
+    def get_hor_vis_lines(self):
+        return getattr(self, "hor_vis_lines", [])
+
+    def get_ver_vis_lines(self):
+        return getattr(self, "ver_vis_lines", [])
+
 
 class Document(TextBlock):
     """
@@ -404,7 +428,6 @@ class Document(TextBlock):
         super().__init__(delimiter=PAGE_DELIMITER, children=children)
 
         self.set_length()
-
         for text_block in TextBlock.pre_order_traversal(self):
             text_block.set_start_index()
             text_block.set_end_index()
@@ -474,3 +497,42 @@ class Document(TextBlock):
 
         """
         return self.get_text_block(index, Page)
+
+
+class Cell:
+    def __init__(self, bounding_box: BoundingBox, words: list[Word] = None):
+        self.bounding_box = bounding_box
+        self.words = words
+
+    def get_words(self):
+        return self.words or []
+
+    def set_words(self, words: list[Word]):
+        self.words = words
+
+    def filter_words_inside_cell(self, words: list[Word]) -> list[Word]:
+        bounded_words = []
+        for word in words:
+            if self.bounding_box.contains_point(word.bounding_box.get_center()):
+                bounded_words.append(word)
+        return bounded_words
+
+
+class Table:
+    def __init__(self, cells: list[Cell]):
+        self.cells = cells
+        self.bounding_box = self.get_bounding_box()
+
+    def get_bounding_box(self):
+        return BoundingBox.compose_bounding_boxes(
+            [cell.bounding_box for cell in self.cells]
+        )
+
+    def group_words_into_cells(self, words: list[Word]):
+        table_words = []
+        for word in words:
+            if self.bounding_box.contains_point(word.bounding_box.get_center()):
+                table_words.append(word)
+        for cell in self.cells:
+            cell_words = cell.filter_words_inside_cell(table_words)
+            cell.set_words(cell_words)
